use shell_rs::mkdir;

fn main() {
    let options = mkdir::Options {
        parents: true,
        mode: 0o777,
        ..Default::default()
    };

    let ret = mkdir::mkdir("~/Desktop/a/b/c/d${HOME}${HOME}/${USER}/a/b/c/", &options);
    println!("ret: {:?}", ret);
}
